
# Slot: regulates




URI: [biolink:regulates](https://w3id.org/biolink/vocab/regulates)


## Domain and Range

[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md) &#8594;  <sub>0..1</sub> [PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)

## Parents


## Children

 *  [negatively regulates](negatively_regulates.md)
 *  [positively regulates](positively_regulates.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | This is a grouping for process-process and entity-entity regulation. |
| **Exact Mappings:** | | RO:0002211 |
| **Close Mappings:** | | RO:0002334 |
| **Narrow Mappings:** | | WIKIDATA_PROPERTY:P128 |
|  | | CHEMBL.MECHANISM:modulator |
|  | | RO:0002295 |
|  | | RO:0002332 |
|  | | RO:0002578 |
|  | | RTXKG1:regulates_activity_of |
|  | | RTXKG1:regulates_expression_of |

